@@ -19,7 +19,16 @@ _initialized = False
 _consumers_enabled = True
 
 
-def __init__(enable_consumers: bool = True):
+def __init__(enable_consumers: bool = True,
+             prefetch_count: int = 1,
+             global_prefetch: bool = False):
+    """
+    Initialize queue module
+    :param enable_consumers: register consumers
+    :param prefetch_count: maximum unacknowledged messages per channel
+    :param global_prefetch: set prefetch limit on connection instead of channel
+    :return:
+    """
     global _initialized
     global _consumers_enabled
 
@@ -41,7 +50,9 @@ def __init__(enable_consumers: bool = True):
 
     routing.__init__()
     if enable_consumers:
-        consumer.__init__(connection_factory)
+        consumer.__init__(connection_factory,
+                          prefetch_count=prefetch_count,
+                          global_prefetch=global_prefetch)
 
     publisher.__init__(connection_factory)
 
