@@ -80,8 +80,11 @@ class MessageListener:
 
 class ConsumerLoop:
     def __init__(self, connection: ReconnectingAMQPConnection,
-                 reconnection_delay: float = 3, reconnection_retries: int = 50,
-                 execution_delay: float = 5, prefetch_count: int = 3):
+                 reconnection_delay: float = 3,
+                 reconnection_retries: int = 50,
+                 execution_delay: float = 5,
+                 prefetch_count: int = 3,
+                 global_prefetch: bool = False):
         """
             Class that manages a channel, implements reconnecting mechanism and allow listeners for queues.
             It's recommended to have only one listener per loop due to Pika limitations
@@ -91,6 +94,7 @@ class ConsumerLoop:
             :param reconnection_retries: maximum retries before declaring the connection lost
             :param execution_delay: seconds to wait after initialization before start consuming
             :param prefetch_count: number of messages to be prefetched in advanced
+            :param global_prefetch: set prefetch limit on connection instead of channel
         """
         assert connection is not None
 
@@ -103,7 +107,8 @@ class ConsumerLoop:
         self._reconnection_delay: float = reconnection_delay
         self._reconnection_retries: int = reconnection_retries
         self._execution_delay: float = execution_delay
-        self._prefect_count = prefetch_count
+        self._prefect_count: int = prefetch_count
+        self._global_prefetch: bool = global_prefetch
         self._loop: Thread = Thread(name='consumer-loop', target=ConsumerLoop._consumer_loop, args=[self], daemon=True)
 
         self._open_channel()
@@ -123,7 +128,7 @@ class ConsumerLoop:
                         self._channel = self._connection.channel()
                         assert not self._channel_closed()
 
-                        self._channel.basic_qos(prefetch_count=self._prefect_count)
+                        self._channel.basic_qos(prefetch_count=self._prefect_count, global_qos=self._global_prefetch)
 
                         for queue in self._queues_listener:
                             self._declare_queue(queue)
@@ -264,18 +269,24 @@ class ConsumerLoop:
 
 
 class ConsumerManager(MessageListener):
-    def __init__(self, connection_factory: ConnectionFactory, prefetch_count: int = 1):
+    def __init__(self, connection_factory: ConnectionFactory,
+                 prefetch_count: int = 1,
+                 global_prefetch: bool = False):
         """
         Manager of consumers of a queue.
         It creates a channel for each new consumer that can be configured by the attributes in the Consumer
         :param connection_factory: AMQP connection factory
+        :param prefetch_count: maximum unacknowledged messages per channel
+        :param global_prefetch: set prefetch limit on connection instead of channel
         """
         assert connection_factory is not None
 
         self._connection_factory: ConnectionFactory = connection_factory
         self._lock: RLock = RLock()
         self._consumer_loop: ConsumerLoop = \
-            ConsumerLoop(self._connection_factory.create(), prefetch_count=prefetch_count)
+            ConsumerLoop(self._connection_factory.create(),
+                         prefetch_count=prefetch_count,
+                         global_prefetch=global_prefetch)
         self._queue_consumers: Dict[str, List[Consumer]] = {}
 
     def add_consumer(self, consumer: Consumer):
@@ -347,10 +358,14 @@ class ConsumerManager(MessageListener):
 consumer_manager: Optional[ConsumerManager]
 
 
-def __init__(connection_factory: ConnectionFactory):
+def __init__(connection_factory: ConnectionFactory,
+             prefetch_count: int = 1,
+             global_prefetch: bool = False):
     global consumer_manager
 
-    consumer_manager = ConsumerManager(connection_factory)
+    consumer_manager = ConsumerManager(connection_factory,
+                                       prefetch_count=prefetch_count,
+                                       global_prefetch=global_prefetch)
 
 
 def close():
