@@ -23,13 +23,14 @@ class Publisher:
         self._closed: bool = False
         self._lock: RLock = RLock()
 
-    def push(self, message, ttl_millis: Optional[int] = environment.RABBITMQ_TTL_MILLIS):
+    def push(self, message, ttl_millis: Optional[int] = None, headers: Dict[str, str] = None):
         routes: List[Route] = routing.get_routes(message)
 
-        self.push_to_routes(message=message, routes=routes, ttl_millis=ttl_millis)
+        self.push_to_routes(message=message, routes=routes, ttl_millis=ttl_millis, headers=headers)
 
     def push_to_routes(self, message, routes: List[Route],
-                       ttl_millis: Optional[int] = environment.RABBITMQ_TTL_MILLIS):
+                       ttl_millis: Optional[int] = None,
+                       headers: Dict[str, str] = None):
         from .parse import encode
 
         if self._closed:
@@ -38,16 +39,22 @@ class Publisher:
         if not len(routes):
             raise NoRouteFoundException(f'No route found for message: {str(message)}')
 
+        if headers is None:
+            headers = {}
+
         body, content_type = encode(message)
+        default_headers = {
+            'Content-Type': content_type,
+            'Content-Length': len(body)
+        }
+
+        headers.update(default_headers)
 
         properties: BasicProperties = BasicProperties(
             content_type=content_type,
             delivery_mode=2,  # persistent
-            expiration=str(ttl_millis),
-            headers={
-                'Content-Type': content_type,
-                'Content-Length': len(body)
-            }
+            expiration=str(ttl_millis) if ttl_millis is not None else None,
+            headers=headers
         )
 
         with self._lock:
